@@ -15,7 +15,7 @@ use Path::Class;
 use File::chdir;
 use Group::Git::Repo;
 
-our $VERSION     = version->new('0.1.3');
+our $VERSION     = version->new('0.1.4');
 our $AUTOLOAD;
 
 has conf => (
@@ -33,8 +33,9 @@ has recurse => (
     isa => 'Bool',
 );
 has verbose => (
-    is  => 'rw',
-    isa => 'Int',
+    is      => 'rw',
+    isa     => 'Int',
+    default => 0,
 );
 has test => (
     is  => 'rw',
@@ -133,7 +134,7 @@ Group::Git - Base module for group of git repository operations.
 
 =head1 VERSION
 
-This documentation refers to Group::Git version 0.1.3.
+This documentation refers to Group::Git version 0.1.4.
 
 =head1 SYNOPSIS
 
